# *stamina*: Production-grade Retries Made Easy

Release **{sub-ref}`release`**  ([What's new?](https://github.com/hynek/stamina/blob/main/CHANGELOG.md))

```{include} ../README.md
:start-after: "---"
:end-before: "<!-- end docs index -->"
```

---

Check out {doc}`motivation` if you need more convincing, or jump into our {doc}`tutorial` to get started right away!


```{toctree}
:hidden: true

motivation
tutorial
instrumentation
api
credits
```

```{toctree}
:hidden:
:caption: Meta

PyPI <https://pypi.org/project/stamina/>
GitHub <https://github.com/hynek/stamina/>
Changelog <https://github.com/hynek/stamina/blob/main/CHANGELOG.md>
Contributing <https://github.com/hynek/stamina/blob/main/.github/CONTRIBUTING.md>
Security Policy <https://github.com/hynek/stamina/blob/main/.github/SECURITY.md>
Funding <https://hynek.me/say-thanks/>
```
